# Changelog

## [3.3.3a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/3.3.3a1) (2025-01-09)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/3.3.2...3.3.3a1)

**Merged pull requests:**

- fix: stop get\_response [\#323](https://github.com/OpenVoiceOS/OVOS-workshop/pull/323) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
